@@ -397,7 +397,7 @@ func (e *Evaluator) expandDynamicBlock(b *Block) {
 		blockName := sub.TypeLabel()
 		// Remove all the child blocks with the blockName so that we don't inject the expanded blocks twice.
 		// This could happen if a module "reloads" and the input variables change.
-		b.RemoveBlocks(blockName)
+		b.RemoveDynamicBlocks(blockName)
 
 		expanded := e.expandBlockForEaches([]*Block{sub})
 		for _, ex := range expanded {
@@ -459,11 +459,11 @@ func (e *Evaluator) expandBlockForEaches(blocks Blocks) Blocks {
 		}
 
 		if block.IsCountExpanded() || !block.IsForEachReferencedExpanded(blocks) || !shouldExpandBlock(block) {
-			parent := block.parent.GetAttribute("for_each")
-			if !parent.HasChanged() {
+			original := block.original.GetAttribute("for_each")
+			if !original.HasChanged() {
 				expanded = append(expanded, block)
 			} else {
-				haveChanged[block.parent.FullName()] = block.parent
+				haveChanged[block.original.FullName()] = block.original
 			}
 
 			continue
@@ -546,11 +546,11 @@ func (e *Evaluator) expandBlockCounts(blocks Blocks) Blocks {
 		}
 
 		if block.IsCountExpanded() || !shouldExpandBlock(block) {
-			parent := block.parent.GetAttribute("count")
-			if !parent.HasChanged() {
+			original := block.original.GetAttribute("count")
+			if !original.HasChanged() {
 				expanded = append(expanded, block)
 			} else {
-				haveChanged[block.parent.FullName()] = block.parent
+				haveChanged[block.original.FullName()] = block.original
 			}
 
 			continue
@@ -1003,7 +1003,7 @@ func ExpFunctions(baseDir string, logger *logrus.Entry) map[string]function.Func
 		"split":            stdlib.SplitFunc,
 		"strrev":           stdlib.ReverseFunc,
 		"substr":           stdlib.SubstrFunc,
-		"timestamp":        funcs.TimestampFunc,
+		"timestamp":        funcs.MockTimestampFunc, // We want to return a deterministic value each time
 		"timeadd":          stdlib.TimeAddFunc,
 		"title":            stdlib.TitleFunc,
 		"tostring":         funcs.MakeToFunc(cty.String),
