@@ -1,6 +1,7 @@
 package google
 
 import (
+	"github.com/infracost/infracost/internal/providers/terraform/provider_schemas"
 	"github.com/infracost/infracost/internal/schema"
 	"github.com/tidwall/gjson"
 )
@@ -34,10 +35,16 @@ func GetResourceRegion(resourceType string, v gjson.Result) string {
 	return ""
 }
 
-func ParseTags(resourceType string, v gjson.Result) map[string]string {
+func ParseTags(resourceType string, r gjson.Result) *map[string]string {
+	_, supportsTags := provider_schemas.GoogleLabelsSupport[resourceType]
+	rLabels := r.Get("labels").Map()
+	if !supportsTags && len(rLabels) == 0 {
+		return nil
+	}
+
 	tags := make(map[string]string)
-	for k, v := range v.Get("labels").Map() {
+	for k, v := range rLabels {
 		tags[k] = v.String()
 	}
-	return tags
+	return &tags
 }
