@@ -2,9 +2,10 @@ package terraform
 
 import (
 	"bytes"
-	"encoding/json"
+	stdJson "encoding/json"
 	"fmt"
 	"regexp"
+	"sort"
 	"strconv"
 	"strings"
 
@@ -40,7 +41,7 @@ func (p *Parser) createPartialResource(d *schema.ResourceData, u *schema.UsageDa
 	registryMap := GetResourceRegistryMap()
 
 	for cKey, cValue := range getSpecialContext(d) {
-		p.ctx.SetContextValue(cKey, cValue)
+		p.ctx.ContextValues.SetValue(cKey, cValue)
 	}
 
 	if registryItem, ok := (*registryMap)[d.Type]; ok {
@@ -52,6 +53,7 @@ func (p *Parser) createPartialResource(d *schema.ResourceData, u *schema.UsageDa
 					IsSkipped:   true,
 					NoPrice:     true,
 					SkipMessage: "Free resource.",
+					Metadata:    d.Metadata,
 				},
 				CloudResourceIDs: registryItem.CloudResourceIDFunc(d),
 			}
@@ -84,6 +86,7 @@ func (p *Parser) createPartialResource(d *schema.ResourceData, u *schema.UsageDa
 			Name:        d.Address,
 			IsSkipped:   true,
 			SkipMessage: "This resource is not currently supported",
+			Metadata:    d.Metadata,
 		},
 	}
 }
@@ -128,13 +131,13 @@ func (p *Parser) populateUsageData(resData map[string]*schema.ResourceData, usag
 	}
 }
 
-func (p *Parser) parseJSON(j []byte, usage schema.UsageMap) ([]*schema.PartialResource, []*schema.PartialResource, error) {
+func (p *Parser) parseJSON(j []byte, usage schema.UsageMap) ([]*schema.PartialResource, []*schema.PartialResource, []schema.ProviderMetadata, error) {
 	baseResources := p.loadUsageFileResources(usage)
 
 	j, _ = StripSetupTerraformWrapper(j)
 
 	if !gjson.ValidBytes(j) {
-		return baseResources, baseResources, errors.New("invalid JSON")
+		return baseResources, baseResources, nil, errors.New("invalid JSON")
 	}
 
 	parsed := gjson.ParseBytes(j)
@@ -144,26 +147,60 @@ func (p *Parser) parseJSON(j []byte, usage schema.UsageMap) ([]*schema.PartialRe
 	conf := parsed.Get("configuration.root_module")
 	vars := parsed.Get("variables")
 
+	providerMetadata := parseProviderConfig(providerConf)
+
 	resources := p.parseJSONResources(false, baseResources, usage, parsed, providerConf, conf, vars)
 	if !p.includePastResources {
-		return nil, resources, nil
+		return nil, resources, providerMetadata, nil
 	}
 
 	if !parsed.Get("prior_state").Exists() {
-		return nil, resources, nil
+		return nil, resources, providerMetadata, nil
 	}
 
 	// Check if the prior state is the same as the planned state
 	// and if so we can just return pointers to the same resources
 	if gjsonEqual(parsed.Get("prior_state.values.root_module"), parsed.Get("planned_values.root_module")) {
-		return resources, resources, nil
+		return resources, resources, providerMetadata, nil
 	}
 
 	pastResources := p.parseJSONResources(true, baseResources, usage, parsed, providerConf, conf, vars)
 	resourceChanges := parsed.Get("resource_changes").Array()
 	pastResources = stripNonTargetResources(pastResources, resources, resourceChanges)
 
-	return pastResources, resources, nil
+	return pastResources, resources, providerMetadata, nil
+}
+
+func parseProviderConfig(providerConf gjson.Result) []schema.ProviderMetadata {
+	var metadatas []schema.ProviderMetadata
+
+	for _, conf := range providerConf.Map() {
+		md := schema.ProviderMetadata{
+			Name:      conf.Get("name").String(),
+			Filename:  conf.Get("infracost_metadata.filename").String(),
+			StartLine: conf.Get("infracost_metadata.start_line").Int(),
+			EndLine:   conf.Get("infracost_metadata.end_line").Int(),
+		}
+
+		for _, defaultTags := range conf.Get("expressions.default_tags").Array() {
+			if md.DefaultTags == nil {
+				md.DefaultTags = make(map[string]string)
+			}
+
+			for key, value := range defaultTags.Get("tags.constant_value").Map() {
+				md.DefaultTags[key] = value.String()
+			}
+		}
+
+		metadatas = append(metadatas, md)
+	}
+
+	// Sort the metadata by name so any outputted JSON is deterministic
+	sort.Slice(metadatas, func(i, j int) bool {
+		return metadatas[i].Name < metadatas[j].Name
+	})
+
+	return metadatas
 }
 
 // StripSetupTerraformWrapper removes any output added from the setup-terraform
@@ -186,7 +223,7 @@ func (p *Parser) loadUsageFileResources(u schema.UsageMap) []*schema.PartialReso
 	for k, v := range u.Data() {
 		for _, t := range GetUsageOnlyResources() {
 			if strings.HasPrefix(k, fmt.Sprintf("%s.", t)) {
-				d := schema.NewResourceData(t, "global", k, map[string]string{}, gjson.Result{})
+				d := schema.NewResourceData(t, "global", k, nil, gjson.Result{})
 				// set the usage data as a field on the resource data in case it is needed when
 				// processing reference attributes.
 				d.UsageData = v
@@ -271,7 +308,8 @@ func (p *Parser) parseResourceData(isState bool, providerConf, planVals gjson.Re
 
 		v = schema.AddRawValue(v, "region", region)
 
-		tags := parseTags(t, v)
+		defaultTags := parseDefaultTags(providerConf, resConf)
+		tags := parseTags(defaultTags, t, v)
 
 		data := schema.NewResourceData(t, provider, addr, tags, v)
 		data.Metadata = r.Get("infracost_metadata").Map()
@@ -304,19 +342,37 @@ func getSpecialContext(d *schema.ResourceData) map[string]interface{} {
 	}
 }
 
-func parseTags(resourceType string, v gjson.Result) map[string]string {
+func parseDefaultTags(providerConf, resConf gjson.Result) *map[string]string {
+	// this only works for aws, we'll need to review when other providers support default tags
+	providerKey := parseProviderKey(resConf)
+	dTagsArray := providerConf.Get(fmt.Sprintf("%s.expressions.default_tags", gjsonEscape(providerKey))).Array()
+	if len(dTagsArray) == 0 {
+		return nil
+	}
+
+	defaultTags := make(map[string]string)
+	for _, dTags := range dTagsArray {
+		for k, v := range dTags.Get("tags.constant_value").Map() {
+			defaultTags[k] = v.String()
+		}
+	}
+
+	return &defaultTags
+}
+
+func parseTags(defaultTags *map[string]string, resourceType string, v gjson.Result) *map[string]string {
 	providerPrefix := getProviderPrefix(resourceType)
 
 	switch providerPrefix {
 	case "aws":
-		return aws.ParseTags(resourceType, v)
+		return aws.ParseTags(defaultTags, resourceType, v)
 	case "azurerm":
 		return azure.ParseTags(resourceType, v)
 	case "google":
 		return google.ParseTags(resourceType, v)
 	default:
 		logging.Logger.Debugf("Unsupported provider %s", providerPrefix)
-		return map[string]string{}
+		return nil
 	}
 }
 
@@ -797,14 +853,14 @@ func gjsonEqual(a, b gjson.Result) bool {
 	var err error
 
 	var aOut bytes.Buffer
-	err = json.Compact(&aOut, []byte(a.Raw))
+	err = stdJson.Compact(&aOut, []byte(a.Raw))
 	if err != nil {
 		logging.Logger.Debugf("error indenting JSON: %s", err)
 		return false
 	}
 
 	var bOut bytes.Buffer
-	err = json.Compact(&bOut, []byte(b.Raw))
+	err = stdJson.Compact(&bOut, []byte(b.Raw))
 	if err != nil {
 		logging.Logger.Debugf("error indenting JSON: %s", err)
 		return false
