@@ -3,6 +3,7 @@ package google
 import (
 	"github.com/shopspring/decimal"
 
+	"github.com/infracost/infracost/internal/logging"
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
 )
@@ -44,11 +45,14 @@ func (r *ContainerNodePool) BuildResource() *schema.Resource {
 
 	poolSize := int64(1)
 
-	costComponents := []*schema.CostComponent{
-		computeCostComponent(r.Region, r.NodeConfig.MachineType, r.NodeConfig.PurchaseOption, poolSize, nil),
-		computeDiskCostComponent(r.Region, r.NodeConfig.DiskType, r.NodeConfig.DiskSize, poolSize),
+	costComponents, err := computeCostComponents(r.Region, r.NodeConfig.MachineType, r.NodeConfig.PurchaseOption, poolSize, nil)
+	if err != nil {
+		logging.Logger.Warnf("Skipping resource %s. %s", r.Address, err)
+		return nil
 	}
 
+	costComponents = append(costComponents, computeDiskCostComponent(r.Region, r.NodeConfig.DiskType, r.NodeConfig.DiskSize, poolSize))
+
 	if r.NodeConfig.LocalSSDCount > 0 {
 		costComponents = append(costComponents, scratchDiskCostComponent(r.Region, r.NodeConfig.PurchaseOption, int(r.NodeConfig.LocalSSDCount)))
 	}
